import json
import requests
from .exceptions import APIError


class Chat:
    def __init__(self, api_key, text, model):
        self.api_key = api_key
        self.text = text
        self.model = model
        self.session = requests.Session()

    def get_response(self):
        params = {
            'api_key': self.api_key,
            'prompt': self.text
        }
        try:
            response = self.session.get(
                f'https://api.progressiveai.org/v1/{self.model}/chat', params=params, timeout=95)
            response.raise_for_status()
            data = response.json()
        except requests.exceptions.HTTPError as errh:
            if response.status_code == 404:
                print("The AI Model is unavailable or doesn't exist at all!")
            elif response.status_code == 524:  # Cloudflare Timeout Error
                print("The request timed out. Please try again later.")
            elif response.status_code == 502:
                print("Oops! The Server failed to return a response!")
            else:
                print("HTTP Error: ", errh)
            return None
        except requests.exceptions.ConnectionError as errc:
            print(f"Error Connecting: {errc}")
            return None
        except requests.exceptions.Timeout as errt:
            print(f"Timeout Error: {errt}")
            return None
        except requests.exceptions.RequestException as err:
            print(f"Something went wrong with the request: {err}")
            return None
        except Exception as e:
            print(f"An error occurred: {e}")
            return None

        if 'error' in data:
            raise APIError(data['error'])
        return data['response']



import aiohttp
import asyncio
import json
from progressiveai import APIError


class ChatAsync:
    def __init__(self, api_key, text, model):
        self.api_key = api_key
        self.text = text
        self.model = model

    async def get_response(self):
        params = {
            'api_key': self.api_key,
            'prompt': self.text
        }

        try:
            async with aiohttp.ClientSession() as session:
                async with session.get(
                        f'https://api.progressiveai.org/v1/{self.model}/chat', params=params, timeout=95) as response:
                    response.raise_for_status()
                    data = await response.json()
        except asyncio.TimeoutError as toe:
            print("The request timed out. Please try again later.")
            return None
        except aiohttp.ServerDisconnectedError as sde:
            print("The Server disconnected. Please try again later.")
            return None
        except aiohttp.ClientResponseError as cre:
            if cre.status == 404:
                print("The AI Model is unavailable or doesn't exist at all!")
            elif cre.status == 524:  # Cloudflare Timeout Error
                print("The request timed out. Please try again later.")
            elif cre.status == 502:
                print("Oops! The Server failed to return a response!")
            else:
                print("Client response error: ", cre)
            return None
        except aiohttp.ClientPayloadError as cpe:
            print(f"Client payload error: {cpe}")
            return None
        except json.JSONDecodeError as jde:
            print(f"JSON decoding error: {jde}")
            return None
        except aiohttp.ClientError as ce:
            print(f"Aiohttp client error: {ce}")
            return None
        except Exception as e:
            print(f"An unexpected error occurred: {e}")
            return None

        # Use get() to avoid KeyError if 'response' is not present in data
        return data.get('response')



import requests
import json
from .exceptions import APIError


class Complete:
    def __init__(self, api_key, text, model):
        self.api_key = api_key
        self.text = text
        self.model = model
        self.session = requests.Session()

    def get_response(self):
        params = {
            'api_key': self.api_key,
            'prompt': self.text
        }
        response = self.session.get(
            f'https://api.progressiveai.org/v1/{self.model}/complete', params=params)
        try:
            data = response.json()
        except requests.exceptions.HTTPError as errh:
            if response.status_code == 404:
                print("The AI Model is unavailable or doesn't exist at all!")
                raise
            elif response.status_code == 524:  # Cloudflare Timeout Error
                print("The request timed out. Please try again later.")
                raise
            elif response.status_code == 502:
                print("Opps! The Server failed to return a response!")
            else:
                print("HTTP Error: ", errh)
                raise
        except json.JSONDecodeError as e:
            print(f"JSON decoding error: {e}")
            print(f"Status code: {response.status_code}")
            print(f"Response content: {response.content}")
            raise
        except requests.exceptions.ConnectionError as errc:
            print("Error Connecting: ", errc)
            raise
        except requests.exceptions.Timeout as errt:
            print("Timeout Error: ", errt)
            raise
        except requests.exceptions.RequestException as err:
            print("Something went wrong with the request: ", err)
            raise
        if 'error' in data:
            raise APIError(data['error'])
        return data['response']

# Usage:
# api_key = 'your-api-key'
# model = 'your-model'
# text = 'your-text'
# complete = Complete(api_key, model)
# print(complete.get_response(text))
